@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2024 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -20,7 +20,11 @@
 */
 #include "../../SDL_internal.h"
 
-#if SDL_VIDEO_DRIVER_X11
+#ifdef SDL_VIDEO_DRIVER_X11
+
+#ifdef __CYGWIN__
+#undef SDL_VIDEO_DRIVER_WINDOWS
+#endif
 
 #include "SDL_x11video.h"
 #include "SDL_x11framebuffer.h"
@@ -127,7 +131,7 @@ int X11_CreateWindowFramebuffer(_THIS, SDL_Window *window, Uint32 *format,
 #endif /* not NO_SHARED_MEMORY */
 
     *pixels = SDL_malloc((size_t)h * (*pitch));
-    if (*pixels == NULL) {
+    if (!*pixels) {
         return SDL_OutOfMemory();
     }
 
@@ -226,7 +230,7 @@ void X11_DestroyWindowFramebuffer(_THIS, SDL_Window *window)
     SDL_WindowData *data = (SDL_WindowData *)window->driverdata;
     Display *display;
 
-    if (data == NULL) {
+    if (!data) {
         /* The window wasn't fully initialized */
         return;
     }
